pub enum GetTagValuesError {
InternalService(String),
InvalidParameter(String),
PaginationTokenExpired(String),
Throttled(String),
}Expand description
Errors returned by GetTagValues
Variants
InternalService(String)
The request processing failed because of an unknown error, exception, or failure. You can retry the request.
InvalidParameter(String)
This error indicates one of the following:
-
A parameter is missing.
-
A malformed string was supplied for the request parameter.
-
An out-of-range value was supplied for the request parameter.
-
The target ID is invalid, unsupported, or doesn't exist.
-
You can't access the Amazon S3 bucket for report storage. For more information, see Additional Requirements for Organization-wide Tag Compliance Reports in the AWS Organizations User Guide.
PaginationTokenExpired(String)
A PaginationToken is valid for a maximum of 15 minutes. Your request was denied because the specified PaginationToken has expired.
Throttled(String)
The request was denied to limit the frequency of submitted requests.
Implementations
Sourceimpl GetTagValuesError
impl GetTagValuesError
pub fn from_response( res: BufferedHttpResponse, ) -> RusotoError<GetTagValuesError>