[−][src]Enum rusoto_resourcegroupstaggingapi::TagResourcesError
Errors returned by TagResources
Variants
InternalService(String)The request processing failed because of an unknown error, exception, or failure. You can retry the request.
InvalidParameter(String)This error indicates one of the following:
-
A parameter is missing.
-
A malformed string was supplied for the request parameter.
-
An out-of-range value was supplied for the request parameter.
-
The target ID is invalid, unsupported, or doesn't exist.
-
You can't access the Amazon S3 bucket for report storage. For more information, see Additional Requirements for Organization-wide Tag Compliance Reports in the AWS Organizations User Guide.
Throttled(String)The request was denied to limit the frequency of submitted requests.
Methods
impl TagResourcesError[src]
pub fn from_response(
res: BufferedHttpResponse
) -> RusotoError<TagResourcesError>[src]
res: BufferedHttpResponse
) -> RusotoError<TagResourcesError>