Enum rusoto_resourcegroupstaggingapi::UntagResourcesError [−][src]
pub enum UntagResourcesError {
InternalService(String),
InvalidParameter(String),
Throttled(String),
HttpDispatch(HttpDispatchError),
Credentials(CredentialsError),
Validation(String),
Unknown(String),
}Errors returned by UntagResources
Variants
InternalService(String)The request processing failed because of an unknown error, exception, or failure. You can retry the request.
InvalidParameter(String)A parameter is missing or a malformed string or invalid or out-of-range value was supplied for the request parameter.
Throttled(String)The request was denied to limit the frequency of submitted requests.
HttpDispatch(HttpDispatchError)An error occurred dispatching the HTTP request
Credentials(CredentialsError)An error was encountered with AWS credentials.
Validation(String)A validation error occurred. Details from AWS are provided.
Unknown(String)An unknown error occurred. The raw HTTP response is provided.
Methods
impl UntagResourcesError[src]
impl UntagResourcesErrorpub fn from_body(body: &str) -> UntagResourcesError[src]
pub fn from_body(body: &str) -> UntagResourcesErrorTrait Implementations
impl Debug for UntagResourcesError[src]
impl Debug for UntagResourcesErrorfn fmt(&self, f: &mut Formatter) -> Result[src]
fn fmt(&self, f: &mut Formatter) -> ResultFormats the value using the given formatter. Read more
impl PartialEq for UntagResourcesError[src]
impl PartialEq for UntagResourcesErrorfn eq(&self, other: &UntagResourcesError) -> bool[src]
fn eq(&self, other: &UntagResourcesError) -> boolThis method tests for self and other values to be equal, and is used by ==. Read more
fn ne(&self, other: &UntagResourcesError) -> bool[src]
fn ne(&self, other: &UntagResourcesError) -> boolThis method tests for !=.
impl From<Error> for UntagResourcesError[src]
impl From<Error> for UntagResourcesErrorfn from(err: Error) -> UntagResourcesError[src]
fn from(err: Error) -> UntagResourcesErrorPerforms the conversion.
impl From<CredentialsError> for UntagResourcesError[src]
impl From<CredentialsError> for UntagResourcesErrorfn from(err: CredentialsError) -> UntagResourcesError[src]
fn from(err: CredentialsError) -> UntagResourcesErrorPerforms the conversion.
impl From<HttpDispatchError> for UntagResourcesError[src]
impl From<HttpDispatchError> for UntagResourcesErrorfn from(err: HttpDispatchError) -> UntagResourcesError[src]
fn from(err: HttpDispatchError) -> UntagResourcesErrorPerforms the conversion.
impl From<Error> for UntagResourcesError[src]
impl From<Error> for UntagResourcesErrorfn from(err: Error) -> UntagResourcesError[src]
fn from(err: Error) -> UntagResourcesErrorPerforms the conversion.
impl Display for UntagResourcesError[src]
impl Display for UntagResourcesErrorfn fmt(&self, f: &mut Formatter) -> Result[src]
fn fmt(&self, f: &mut Formatter) -> ResultFormats the value using the given formatter. Read more
impl Error for UntagResourcesError[src]
impl Error for UntagResourcesErrorAuto Trait Implementations
impl Send for UntagResourcesError
impl Send for UntagResourcesErrorimpl Sync for UntagResourcesError
impl Sync for UntagResourcesError