pub struct Summary {
pub last_updated: Option<String>,
pub non_compliant_resources: Option<i64>,
pub region: Option<String>,
pub resource_type: Option<String>,
pub target_id: Option<String>,
pub target_id_type: Option<String>,
}Expand description
A count of noncompliant resources.
Fields
last_updated: Option<String>The timestamp that shows when this summary was generated in this Region.
non_compliant_resources: Option<i64>The count of noncompliant resources.
region: Option<String>The AWS Region that the summary applies to.
resource_type: Option<String>The AWS resource type.
target_id: Option<String>The account identifier or the root identifier of the organization. If you don't know the root ID, you can call the AWS Organizations ListRoots API.
target_id_type: Option<String>Whether the target is an account, an OU, or the organization root.